@@ -1,4 +1,5 @@
 import time
+import six
 
 from aws_xray_sdk.core.recorder import AWSXRayRecorder
 from aws_xray_sdk.core.utils import stacktrace
@@ -53,7 +54,7 @@ class AsyncAWSXRayRecorder(AWSXRayRecorder):
 
     def in_segment_async(self, name=None, **segment_kwargs):
         """
-        Return a segment async context manger.
+        Return a segment async context manager.
 
         :param str name: the name of the segment
         :param dict segment_kwargs: remaining arguments passed directly to `begin_segment`
@@ -62,7 +63,7 @@ class AsyncAWSXRayRecorder(AWSXRayRecorder):
 
     def in_subsegment_async(self, name=None, **subsegment_kwargs):
         """
-        Return a subsegment async context manger.
+        Return a subsegment async context manager.
 
         :param str name: the name of the segment
         :param dict segment_kwargs: remaining arguments passed directly to `begin_segment`
@@ -81,10 +82,10 @@ class AsyncAWSXRayRecorder(AWSXRayRecorder):
         try:
             return_value = await wrapped(*args, **kwargs)
             return return_value
-        except Exception as e:
-            exception = e
+        except Exception as exc:
+            exception = exc
             stack = stacktrace.get_stacktrace(limit=self._max_trace_back)
-            raise
+            six.raise_from(exc, exc)
         finally:
             # No-op if subsegment is `None` due to `LOG_ERROR`.
             if subsegment is not None:
