@@ -4,6 +4,7 @@ import logging
 import os
 import platform
 import time
+import six
 
 from aws_xray_sdk import global_sdk_config
 from aws_xray_sdk.version import VERSION
@@ -232,7 +233,7 @@ class AWSXRayRecorder(object):
         elif sampling:
             decision = sampling
         elif self.sampling:
-            decision = self._sampler.should_trace()
+            decision = self._sampler.should_trace({'service': seg_name})
 
         if not decision:
             segment = DummySegment(seg_name)
@@ -274,16 +275,10 @@ class AWSXRayRecorder(object):
         else:
             return entity
 
-    def begin_subsegment(self, name, namespace='local'):
-        """
-        Begin a new subsegment.
-        If there is open subsegment, the newly created subsegment will be the
-        child of latest opened subsegment.
-        If not, it will be the child of the current open segment.
-
-        :param str name: the name of the subsegment.
-        :param str namespace: currently can only be 'local', 'remote', 'aws'.
-        """
+    def _begin_subsegment_helper(self, name, namespace='local', beginWithoutSampling=False):
+        '''
+        Helper method to begin_subsegment and begin_subsegment_without_sampling
+        '''
         # Generating the parent dummy segment is necessary.
         # We don't need to store anything in context. Assumption here
         # is that we only work with recorder-level APIs.
@@ -294,16 +289,42 @@ class AWSXRayRecorder(object):
         if not segment:
             log.warning("No segment found, cannot begin subsegment %s." % name)
             return None
-
-        if not segment.sampled:
+        
+        current_entity = self.get_trace_entity()
+        if not current_entity.sampled or beginWithoutSampling:
             subsegment = DummySubsegment(segment, name)
         else:
             subsegment = Subsegment(name, namespace, segment)
 
         self.context.put_subsegment(subsegment)
-
         return subsegment
 
+
+
+    def begin_subsegment(self, name, namespace='local'):
+        """
+        Begin a new subsegment.
+        If there is open subsegment, the newly created subsegment will be the
+        child of latest opened subsegment.
+        If not, it will be the child of the current open segment.
+
+        :param str name: the name of the subsegment.
+        :param str namespace: currently can only be 'local', 'remote', 'aws'.
+        """
+        return self._begin_subsegment_helper(name, namespace)
+
+
+    def begin_subsegment_without_sampling(self, name):
+        """
+        Begin a new unsampled subsegment.
+        If there is open subsegment, the newly created subsegment will be the
+        child of latest opened subsegment.
+        If not, it will be the child of the current open segment.
+
+        :param str name: the name of the subsegment.
+        """
+        return self._begin_subsegment_helper(name, beginWithoutSampling=True)
+
     def current_subsegment(self):
         """
         Return the latest opened subsegment. In a multithreading environment,
@@ -435,10 +456,10 @@ class AWSXRayRecorder(object):
         try:
             return_value = wrapped(*args, **kwargs)
             return return_value
-        except Exception as e:
-            exception = e
+        except Exception as exc:
+            exception = exc
             stack = stacktrace.get_stacktrace(limit=self.max_trace_back)
-            raise
+            six.raise_from(exc, exc)
         finally:
             # No-op if subsegment is `None` due to `LOG_ERROR`.
             if subsegment is not None:
@@ -486,7 +507,8 @@ class AWSXRayRecorder(object):
 
     def _stream_subsegment_out(self, subsegment):
         log.debug("streaming subsegments...")
-        self.emitter.send_entity(subsegment)
+        if subsegment.sampled:
+            self.emitter.send_entity(subsegment)
 
     def _load_sampling_rules(self, sampling_rules):
 
